
@import "@synerty/peek-plugin-base-js/src/styles/_variables";
@import "src/variables";

:host {
    display: flex;
    flex-direction: column;
    width: 100%;
}

.card-header {
    display: flex;
    justify-content: space-between;
    align-items: center;
    margin-bottom: $general_margin_2;

    h3 {
        margin: 0;
    }
}

::ng-deep {
    .ant-table {
        .ant-table-thead > tr > th {
            background-color: $background-color;
            color: $font-color-primary;
            font-weight: $semi-bold;
        }

        .ant-table-tbody > tr > td {
            vertical-align: middle;
        }
    }

    .ant-empty {
        margin: $general_margin_2 0;
    }
}