
@import "@synerty/peek-plugin-base-js/src/styles/_variables";
@import "src/variables";

:host {
    display: flex;
    flex-direction: column;
    width: 100%;
}

.search-container {
    margin-top: $general_margin_2;

    .ant-input-group {
        display: flex;
        align-items: center;

        .ant-input-group-suffix {
            margin-left: $general_margin_1;
        }
    }
}

.document-content {
    margin-top: $general_margin_2;

    pre {
        background-color: $background-color;
        padding: $general_padding_2;
        border-radius: $border-radius;
        border: 1px solid $border-color;
        margin: 0;
        overflow-x: auto;
        white-space: pre-wrap;
        word-wrap: break-word;
    }
}

::ng-deep {
    .ant-card {
        h3 {
            margin-bottom: $general_margin_2;
            color: $font-color-primary;
        }
    }

    .ant-empty {
        margin: $general_margin_2 0;
    }

    .ant-divider {
        margin: $general_margin_2 0;
    }
}